qcheck_gleeunit_utils/run
This module provides an alternative to the gleeunit.main function that will run tests in parallel when targeting Erlang. When targeting JavaScript, it will use Gleeunit’s default runner.
Values
pub fn run_gleeunit() -> Nil
Find and run all test functions for the current project using Erlang’s EUnit test framework, or a custom JavaScript test runner.
Any Erlang or Gleam function in the test directory with a name ending in
_test is considered a test function and will be run.
A test that panics is considered a failure.